Broker Client Module Repository
========================

Install with `pip`:

.. code-block::

    pip install git+ssh://git@git.febrace.org.br/swarm-unit/broker-client-python.git


Or, put this on your requirements.txt:

.. code-block::

    git+ssh://git@git.febrace.org.br/swarm-unit/broker-client-python.git
